"""Definition of the Blog content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder
from Products.ATContentTypes.content import schemata

# -*- Message Factory Imported Here -*-
from xhostplus.blog import blogMessageFactory as _
from xhostplus.blog.interfaces import IBlog
from xhostplus.blog.config import PROJECTNAME

BlogSchema = folder.ATFolderSchema.copy() + atapi.Schema((

    # -*- Your Archetypes field definitions here ... -*-

))

# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

BlogSchema['title'].storage = atapi.AnnotationStorage()
BlogSchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(
    BlogSchema,
    folderish=True,
    moveDiscussion=False
)


class Blog(folder.ATFolder):
    """A blog containing blog entries"""
    implements(IBlog)

    meta_type = "Blog"
    schema = BlogSchema

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    # -*- Your ATSchema to Python Property Bridges Here ... -*-

atapi.registerType(Blog, PROJECTNAME)



from string import Template
from Acquisition import aq_inner
from zope.component import getMultiAdapter
from zope.interface import implements

try:
    from Products.CMFPlone import Batch
except ImportError:
    # plone 4.1
    from Products.CMFPlone.PloneBatch import Batch
from Products.Five import BrowserView

from plone.memoize import view

class BlogView(BrowserView):
    """ A blog browser view """

    def __init__(self, context, request):
        super(BlogView, self).__init__(context, request)
        self.context = context
        self.request = request

    @property
    def tools(self):
        return getMultiAdapter((self.context, self.request), name=u'plone_tools')

    @property
    def portal_state(self):
        return getMultiAdapter((self.context, self.request), name=u'plone_portal_state')

    def getFieldValue(self, name, obj=None):
        if obj is None:
            obj = self.context

        field = obj.getField(name)
        if field:
            return field.get(obj)
        return None

    @view.memoize
    def contents(self):
        brains = []
        criteria = {}

        # filter criteria
        subject = self.request.get('subject', None)
        if subject and subject != ['']:
            criteria['Subject'] = subject

        year = self.request.get('publish_year', None)
        if year:
            criteria['publish_year'] = int(year)

        month = self.request.get('publish_month', None)
        if month:
            # Note: months are indexed as for example '03'
            criteria['publish_month'] = month

        criteria['path'] = '/'.join(self.context.getPhysicalPath())
        criteria['portal_type'] = 'Blog Entry'
        criteria['sort_on'] = 'getObjPositionInParent'

        return self.tools.catalog()(criteria)

    def batch(self):
        b_start = self.request.get('b_start', 0)
        return Batch(self.contents(), self.batch_size, int(b_start), orphan=0)

    @property
    def count(self):
        return len(self.contents())

    @property
    def site_props(self):
        pprops = self.tools.properties()
        return getattr(pprops, 'site_properties')

    @property
    def show_body(self):
        field = self.context.getField('enable_full')
        if field:
            return field.get(self.context)
        return False

    @property
    def batch_size(self):
        field = self.context.getField('batch_size')
        if field:
            return field.get(self.context)
        return 10



from zope.interface import Interface

# -*- extra stuff goes here -*-
from blogentry import IBlogEntry
from blog import IBlog

class IProductLayer(Interface):
    """ A layer specific to this product.
        Is registered using browserlayer.xml
    """



from Acquisition import aq_inner
from Acquisition import aq_parent
from OFS.interfaces import IOrderedContainer

def addBlogEntry(obj, event):
    parent = aq_parent(aq_inner(obj))
    ordered = IOrderedContainer(parent, None)
    ordered.moveObjectsToTop((obj.id,))


"""Common configuration constants
"""

PROJECTNAME = 'xhostplus.blog'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'BlogEntry': 'xhostplus.blog: Add Blog Entry',
    'Blog': 'xhostplus.blog: Add Blog',
}



# -*- coding: utf-8 -*-
"""
This module contains the tool of xhostplus.blog
"""
import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

version = '1.0.1'

long_description = (
    read('README.txt')
    + '\n' +
    read('CHANGES.txt')
    )

tests_require = ['zope.testing']

setup(name='xhostplus.blog',
      version=version,
      description="XHOSTPLUS Blog Product for Plone 4",
      long_description=long_description,
      # Get more strings from
      # http://pypi.python.org/pypi?:action=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        ],
      keywords='',
      author='',
      author_email='',
      url='http://www.xhostplus.at/de/services/plone-downlods',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['xhostplus', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        'Products.CMFPlone',
                        # -*- Extra requirements: -*-
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite='xhostplus.blog.tests.test_docs.test_suite',
      entry_points="""
      # -*- entry_points -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      setup_requires=["PasteScript"],
      paster_plugins=["ZopeSkel"],
      )



"""Definition of the Blog Entry content type
"""

from zope.interface import implements

from AccessControl import ClassSecurityInfo

from Products.Archetypes import atapi
from Products.ATContentTypes.content import base
from Products.ATContentTypes.content import schemata

from Products.CMFCore.permissions import View
from Products.CMFCore.utils import getToolByName

# -*- Message Factory Imported Here -*-
from xhostplus.blog import blogMessageFactory as _
from xhostplus.blog.interfaces import IBlogEntry
from xhostplus.blog.config import PROJECTNAME

BlogEntrySchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((

    # -*- Your Archetypes field definitions here ... -*-

    atapi.ImageField(
        'title_image',
        required=False,
        sizes={
            'large'   : (768, 768),
            'preview' : (400, 400),
            'mini'    : (200, 200),
            'thumb'   : (128, 128),
            'tile'    :  (64, 64),
            'icon'    :  (32, 32),
            'listing' :  (16, 16),
        },
        widget=atapi.ImageWidget(
            label=_(u"Title Image"),
        ),
        validators=('isNonEmptyFile'),
    ),

    atapi.StringField(
        name='title_image_caption',
        storage=atapi.AnnotationStorage(),
        required=False,
        searchable=True,
        default='',
        widget=atapi.StringWidget(
            label=_(u"Title Image Caption"),
        ),
    ),

    atapi.TextField(
        'text',
        storage=atapi.AnnotationStorage(),
        required=False,
        widget=atapi.RichWidget(
            label=_(u"Body Text"),
            rows=35,
        ),
    ),

))

# Set storage on fields copied from ATContentTypeSchema, making sure
# they work well with the python bridge properties.

BlogEntrySchema['title'].storage = atapi.AnnotationStorage()
BlogEntrySchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(BlogEntrySchema, moveDiscussion=False)


class BlogEntry(base.ATCTContent):
    """A entry in a blog"""
    implements(IBlogEntry)

    meta_type = "BlogEntry"
    schema = BlogEntrySchema
    security = ClassSecurityInfo()

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    security.declareProtected(View, 'tag')
    def tag(self, **kwargs):
        """Generate image tag using the api of the ImageField
        """
        if 'title' not in kwargs:
            kwargs['title'] = self.title_image_caption
        return self.getField('title_image').tag(self, **kwargs)

    def get_author_portrait(self):
        mtool = getToolByName(self, 'portal_membership')
        portrait = mtool.getPersonalPortrait(id=self.Creator(), verifyPermission=False)
        return portrait

    # -*- Your ATSchema to Python Property Bridges Here ... -*-
    title_image_caption = atapi.ATFieldProperty('title_image_caption')

    text = atapi.ATFieldProperty('text')

atapi.registerType(BlogEntry, PROJECTNAME)
